#define LCRZODEF_LANG 1
#define LCRZODEF_SYS "FreeBSD_4_i386"
#define LCRZODEF_SYS_FreeBSD_4_i386 1
#define LCRZODEF_SYSTEM "FreeBSD"
#define LCRZODEF_SYSTEM_FreeBSD 1
#define LCRZODEF_SYSVER "FreeBSD_4"
#define LCRZODEF_SYSVER_FreeBSD_4 1
#define LCRZODEF_SYSTEMVERS "4"
#define LCRZODEF_SYSTEMVERS_4 1
#define LCRZODEF_SYSTEMARCH "i386"
#define LCRZODEF_SYSTEMARCH_i386 1
#define LCRZODEF_ENDIANLITTLE 1
#define LCRZODEF_ENDIANBIG 0
#define LCRZODEF_VERSION "4.10"
#define LCRZODEF_VERSIONMAJOR 4
#define LCRZODEF_VERSIONMINOR 10
#define LCRZODEF_LIBPCAPINSTALLED 1
#define LCRZODEF_LIBPCAPFROMREDHAT 0
#define LCRZODEF_LIBNETINSTALLED 0
#define LCRZODEF_PROGCC "gcc"
#define LCRZODEF_PROGAR "ar"
#define LCRZODEF_PROGRANLIB "ranlib"
#define LCRZODEF_INSTINCLUDE "/usr/local/include"
#define LCRZODEF_INSTLIB "/usr/local/lib"
#define LCRZODEF_INSTBIN "/usr/local/bin"
#define LCRZODEF_INSTMAN1 "/usr/local/man/man1"
#define LCRZODEF_INSTMAN3 "/usr/local/man/man3"
#define LCRZODEF_INSTUSERGROUP "root:wheel"
#define LCRZODEF_HAVETYPE_SIZE_T 1
#define LCRZODEF_HAVETYPE_SOCKLEN_T 0
#define LCRZODEF_HAVEFONC_ETHER_NTOHOST 1
#define LCRZODEF_HAVEFONC_ETHER_HOSTTON 1
#define LCRZODEF_HAVEFONC_HSTRERROR 1
#define LCRZODEF_HAVEFONC_SNPRINTF 1
#define LCRZODEF_HAVEFONC_IOCTL_BIOCSHDRCMPLT 0
#define LCRZODEF_HAVEFONC_PCAP_FREECODE 1
#define LCRZODEF_HAVEFONC_PCAP_OPENDEAD 1
#define LCRZODEF_HAVEFONC_POLL 0
#define LCRZODEF_HAVEINCL_NETPACKET_PACKET 0
#define LCRZODEF_HAVEINCL_SYS_BUFMOD 0
